# anjl - A neighbour-joining library for Python

`anjl` is a Python package providing fast implementations of the neighbour-joining
algorithm of Saitou and Nei and some associated utilities.

Please see the [documentation](https://alimanfoo.github.io/anjl) for further
information.
